==> blender_2.46+dfsg.orig.tar.gz: blender-2.46.orig/source/gameengine/GameLogic/SCA_PropertyEventManager.cpp <==
/**
 * $Id: SCA_PropertyEventManager.cpp 14444 2008-04-16 22:40:48Z hos $
 * ***** BEGIN GPL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL LICENSE BLOCK *****
 */

#include "SCA_ISensor.h"
#include "SCA_PropertyEventManager.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif


SCA_PropertyEventManager::SCA_PropertyEventManager(class SCA_LogicManager* logicmgr)
	: SCA_EventManager(PROPERTY_EVENTMGR),
	m_logicmgr(logicmgr)
{
}



SCA_PropertyEventManager::~SCA_PropertyEventManager()
{

}



void SCA_PropertyEventManager::RegisterSensor(SCA_ISensor* sensor)
{
	m_sensors.push_back(sensor);
}



void SCA_PropertyEventManager::NextFrame()
{
	// check for changed properties
	for (vector<SCA_ISensor*>::const_iterator it = m_sensors.begin();!(it==m_sensors.end());it++)
	{
		(*it)->Activate(m_logicmgr,NULL);
	}
}

==> blender-2.47.tar.gz: blender-2.47/source/gameengine/GameLogic/SCA_PropertyEventManager.cpp <==
/**
 * $Id: SCA_PropertyEventManager.cpp 15906 2008-08-01 19:49:11Z blendix $
 * ***** BEGIN GPL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL LICENSE BLOCK *****
 */

#include "SCA_ISensor.h"
#include "SCA_PropertyEventManager.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif


SCA_PropertyEventManager::SCA_PropertyEventManager(class SCA_LogicManager* logicmgr)
	: SCA_EventManager(PROPERTY_EVENTMGR),
	m_logicmgr(logicmgr)
{
}



SCA_PropertyEventManager::~SCA_PropertyEventManager()
{

}

void SCA_PropertyEventManager::NextFrame()
{
	// check for changed properties
	for (set<SCA_ISensor*>::const_iterator it = m_sensors.begin();!(it==m_sensors.end());it++)
	{
		(*it)->Activate(m_logicmgr,NULL);
	}
}
